ShimmerButton class

Button-shaped skeleton placeholder.

Inheritance
Available extensions

Constructors

ShimmerButton({Key? key, double? width, double height = 48, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(8)), bool enabled = true})
const

Properties

borderRadius → BorderRadius
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shimmer({Gradient? gradient, Duration period = const Duration(milliseconds: 1500), ShimmerDirection direction = ShimmerDirection.ltr, int loop = 0, bool enabled = true, ShimmerEffect effect = ShimmerEffect.wave, ShimmerController? controller}) → Widget

Available on Widget, provided by the ShimmerWidgetExtension extension

Wraps this widget with Shimmer using a default gradient.
shimmerThemed({Gradient? gradient, ShimmerDirection? direction, Duration? period, int? loop, bool? enabled, ShimmerEffect? effect, ShimmerController? controller}) → Widget

Available on Widget, provided by the ShimmerWidgetExtension extension

Wraps this widget with Shimmer using theme data for defaults.
shimmerWith({required Gradient gradient, Duration period = const Duration(milliseconds: 1500), ShimmerDirection direction = ShimmerDirection.ltr, int loop = 0, bool enabled = true, ShimmerEffect effect = ShimmerEffect.wave, ShimmerController? controller}) → Widget

Available on Widget, provided by the ShimmerWidgetExtension extension

Wraps this widget with Shimmer using a custom gradient.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited